==> awkium-0.1.3-src.tar.gz: awkium/src/net/morilib/awk/builtin/stat/QContinuousUniform.java <==
/*
 * Copyright 2013 Yuichiro Moriguchi
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.morilib.awk.builtin.stat;

import net.morilib.awk.builtin.AwkTernaryArgs;
import net.morilib.awk.io.AwkFiles;
import net.morilib.awk.namespace.AwkNamespace;
import net.morilib.awk.stat.dist.continuous.ContinuousUniformDistribution;
import net.morilib.awk.value.AwkFloat;
import net.morilib.awk.value.AwkValue;

/**
 * 関数stat.qcontinuousuniformの記述です。
 *
 *
 * @author MORIGUCHI, Yuichiro 2013/04/13
 */
public class QContinuousUniform extends AwkTernaryArgs {

	protected QContinuousUniform() {
		super("qcontinuousuniform");
	}

	@Override
	public AwkValue apply(AwkNamespace ns, AwkFiles o, AwkValue a1,
			AwkValue a2, AwkValue a3) {
		double r;

		try {
			r = new ContinuousUniformDistribution(
					a2.toFloat(),
					a3.toFloat()).invCdf(a1.toFloat());
		} catch(IllegalArgumentException e) {
			throw new AwkStatisticsException("Illegal parameter");
		}
		return AwkFloat.valueOf(r);
	}

}

==> awkium-0.2.3-src.tar.gz: awkium/src/net/morilib/awk/builtin/stat/QContinuousUniform.java <==
/*
 * Copyright 2013 Yuichiro Moriguchi
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.morilib.awk.builtin.stat;

import net.morilib.awk.builtin.AwkTernaryArgs;
import net.morilib.awk.io.AwkFiles;
import net.morilib.awk.namespace.AwkNamespace;
import net.morilib.awk.stat.dist.ContinuousUniformDistribution;
import net.morilib.awk.value.AwkFloat;
import net.morilib.awk.value.AwkValue;

/**
 * 関数stat.qcontinuousuniformの記述です。
 *
 *
 * @author MORIGUCHI, Yuichiro 2013/04/13
 */
public class QContinuousUniform extends AwkTernaryArgs {

	protected QContinuousUniform() {
		super("qcontinuousuniform");
	}

	@Override
	public AwkValue apply(AwkNamespace ns, AwkFiles o, AwkValue a1,
			AwkValue a2, AwkValue a3) {
		double r;

		try {
			r = new ContinuousUniformDistribution(
					a2.toFloat(),
					a3.toFloat()).invCdf(a1.toFloat());
		} catch(IllegalArgumentException e) {
			throw new AwkStatisticsException("Illegal parameter");
		}
		return AwkFloat.valueOf(r);
	}

}
